@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "miasma-theme" "1.6.7"
+(define-package "miasma-theme" "20260124.2048"
   "Miasma: color theme inspired by the woods."
   ()
   :url "http://github.com/daut/miasma-theme.el"
